package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.ShipDynamicsMapper;
import com.steerinfo.dil.service.IShipDynamicsService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class ShipDynamicsServiceImpl implements IShipDynamicsService {
    @Autowired
    ShipDynamicsMapper shipDynamicsMapper;

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    //获取视图里的所有外轮船名，物资名称
    public List<Map<String, Object>> selectAll(Map<String,Object> map) {
        return shipDynamicsMapper.selectAll(map);
    }



    @Override
    public List<Map<String, Object>> selectByshipName(String shipName, String materialName) {
        return shipDynamicsMapper.selectByshipName(shipName,materialName);
    }

    @Override
    public List<Map<String, Object>> getLoadData(Map<String,Object> map){
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        return shipDynamicsMapper.getLoadData(map);
    }

    @Override
    public List<Map<String, Object>> getUnloadData(Map<String,Object> map){
        List<Map<String, Object>> list=new ArrayList<>();
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        list.addAll(shipDynamicsMapper.getUnloadData(map));
        list.addAll(shipDynamicsMapper.getLocationData(map));
        boolean f1=false,f2=false,f3=false;
        for(Map<String, Object> temp:list){
            switch (temp.get("status").toString()){
                case "已卸船数":
                    f1=true;
                    break;
                case "待卸船数":
                    f2=true;
                    break;
                case "在卸船数":
                    f3=true;
                    break;
            }
        }
        if(!f1){
            Map<String, Object> m=new HashMap<>();
            m.put("status","已卸船数");
            m.put("num",0);
            list.add(m);
        }
        if(!f2){
            Map<String, Object> m=new HashMap<>();
            m.put("status","待卸船数");
            m.put("num",0);
            list.add(m);
        }
        if(!f3){
            Map<String, Object> m=new HashMap<>();
            m.put("status","在卸船数");
            m.put("num",0);
            list.add(m);
        }
        return list;
    }

    @Override
    public List<Map<String, Object>> getDownShipDynamaics(Map<String,Object> map){
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        return shipDynamicsMapper.getDownShipDynamaics(map);
    }

    @Override
    public List<Map<String, Object>> getWagonWork(Map<String, Object> map) {
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        //把当月时间放进去
        SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM");
        String monthDate = sdfDate.format(new Date());
        map.put("monthDate",monthDate);
        List<Map<String,Object>> list=new ArrayList<>();
        //分别加到里面
        Map<String,Object> pleaseData= shipDynamicsMapper.getPleaseData(map);
        Map<String,Object> map1=new HashMap<>(),map2=new HashMap<>(),map3=new HashMap<>();
        map1.put("dateType","点前剩余计划");
        map2.put("dateType","当日批复计划");
        if(pleaseData!=null){
            map1.put("num",pleaseData.get("surplusSum"));
            map2.put("num",pleaseData.get("approveSum"));
        }else{
            map1.put("num",0);
            map2.put("num",0);
        }
        map3.put("dateType","月累计装车量");
        map3.put("num",shipDynamicsMapper.getRealNumberMonth(map));
        list.add(map1);
        list.add(map2);
        list.add(map3);
        return list;
    }
}
